#!/usr/bin/env bash

inseq=1Y14.fasta
outdir=AF2_1Y14

# ACCRE
module load GCC/10.2.0 Intel/2020.4.304 CUDA/11.1.1
dpath=/csbtmp/alphafold-data/

#workstation
#dpath=/programs/local/alphafold/

source /programs/sbgrid.shrc

export ALPHAFOLD_X=2.2.0

echo "alphafold : $ALPHAFOLD_X"
echo "ptxas:"
ptxas --version

nvidia-smi

if [ ! -d "${outdir}" ] ; then
	mkdir $outdir
fi

echo "starting `date`"

run_alphafold.py --sbwhich

run_alphafold.py    --data_dir=${dpath} \
    --output_dir=${outdir} \
    --fasta_paths=${inseq} \
    --max_template_date=2020-05-14 \
    --db_preset=full_dbs \
    --bfd_database_path=${dpath}/bfd/bfd_metaclust_clu_complete_id30_c90_final_seq.sorted_opt \
    --uniclust30_database_path=${dpath}/uniclust30/uniclust30_2018_08/uniclust30_2018_08  \
    --uniref90_database_path=${dpath}/uniref90/uniref90.fasta \
    --mgnify_database_path=${dpath}/mgnify/mgy_clusters.fa \
    --template_mmcif_dir=${dpath}/pdb_mmcif/mmcif_files \
    --uniprot_database_path=${dpath}/uniprot/uniprot.fasta \
    --pdb_seqres_database_path=${dpath}/pdb_seqres/pdb_seqres.txt \
    --obsolete_pdbs_path=${dpath}/pdb_mmcif/obsolete.dat \
    --use_gpu_relax=True \
    --model_preset=multimer 2> ${outdir}.err

echo "done `date`"

